@@ -20,9 +20,14 @@
 #ifndef INTERVALCHECK_H
 #define INTERVALCHECK_H
 
+#include "entities.h"
+
 #include <QDateTime>
 #include <QHash>
 #include <QThread>
+#include <QMutex>
+
+using namespace Akonadi;
 
 /**
   Interval checking thread.
@@ -35,6 +40,16 @@ class IntervalCheck : public QThread
     IntervalCheck( QObject *parent = 0 );
     ~IntervalCheck();
 
+    static IntervalCheck* instance();
+
+    /**
+     * Requests the given collection to be synced.
+     * Executed from any thread, forwards to triggerCollectionXSync() in the
+     * retrieval thread.
+     * A minimum time interval between two sync requests is ensured.
+     */
+    void requestCollectionSync( const Collection &collection );
+
   protected:
     void run();
 
@@ -42,7 +57,10 @@ class IntervalCheck : public QThread
     void doIntervalCheck();
 
   private:
+    static IntervalCheck* s_instance;
+    QMutex m_lastSyncMutex;
     QHash<int, QDateTime> mLastChecks;
+    QHash<QString, QDateTime> mLastCollectionTreeSyncs;
 };
 
 #endif
