@@ -2,5 +2,5 @@
 # connect to mysqld started by akonadi
 # useful for developing
 
-akonadisocket=$HOME/.local/share/akonadi/db_misc/mysql.socket
+akonadisocket="$HOME/.local/share/akonadi/socket-`hostname`/mysql.socket"
 mysql --socket=$akonadisocket akonadi
