@@ -257,9 +257,23 @@ bool DataStore::appendCollection( Collection &collection )
 bool Akonadi::DataStore::cleanupCollection(Collection &collection)
 {
   // delete the content
-  PimItem::List items = collection.items();
-  foreach ( PimItem item, items )
-    cleanupPimItem( item );
+  const PimItem::List items = collection.items();
+  const QByteArray resource = collection.resource().name().toLatin1();
+  foreach ( const PimItem &item, items ) {
+
+    // generate the notification before actually removing the data
+    mNotificationCollector->itemRemoved( item, collection, QString(), resource ); // TODO: make mimetype available as part as an item bulk query
+
+    if ( !item.clearFlags() ) // TODO: move out of loop and use only a single query
+      return false;
+    if ( !PartHelper::remove( Part::pimItemIdColumn(), item.id() ) ) // TODO: reduce to single query
+      return false;
+    if ( !PimItem::remove( PimItem::idColumn(), item.id() ) ) // TODO: move into single query
+      return false;
+
+    if ( !Entity::clearRelation<CollectionPimItemRelation>( item.id(), Entity::Right ) ) // TODO: move into single query
+      return false;
+  }
 
   // delete collection mimetypes
   collection.clearMimeTypes();
@@ -362,8 +376,9 @@ void DataStore::activeCachePolicy(Collection & col)
   if ( !col.cachePolicyInherit() )
     return;
 
-  Collection parent = col.parent();
-  while ( parent.isValid() ) {
+  Collection parent = col;
+  while ( parent.parentId() != 0 ) {
+    parent = parent.parent();
     if ( !parent.cachePolicyInherit() ) {
       col.setCachePolicyCheckInterval( parent.cachePolicyCheckInterval() );
       col.setCachePolicyCacheTimeout( parent.cachePolicyCacheTimeout() );
@@ -371,7 +386,6 @@ void DataStore::activeCachePolicy(Collection & col)
       col.setCachePolicyLocalParts( parent.cachePolicyLocalParts() );
       return;
     }
-    parent = parent.parent();
   }
 
   // ### system default
@@ -489,40 +503,6 @@ bool DataStore::cleanupPimItem( const PimItem &item )
   return true;
 }
 
-bool DataStore::cleanupPimItems( const Collection &collection )
-{
-  if ( !m_dbOpened || !collection.isValid() )
-    return false;
-
-  QueryBuilder qb( Flag::tableName(), QueryBuilder::Select );
-  qb.addJoin( QueryBuilder::InnerJoin, PimItemFlagRelation::tableName(),
-              PimItemFlagRelation::rightFullColumnName(), Flag::idFullColumnName() );
-  qb.addJoin( QueryBuilder::InnerJoin, PimItem::tableName(),
-              PimItem::idFullColumnName(), PimItemFlagRelation::leftFullColumnName() );
-
-  qb.addColumn( PimItemFlagRelation::leftFullColumnName() );
-
-  qb.addValueCondition( Flag::nameFullColumnName(), Query::Equals, QLatin1String("\\DELETED") );
-  qb.addValueCondition( PimItem::collectionIdFullColumnName(), Query::Equals, collection.id() );
-
-  if ( !qb.exec() )
-    return false;
-
-  QVector<PimItem> pimItems;
-  while ( qb.query().next() ) {
-    PimItem item;
-    item.setId( qb.query().value( 0 ).toLongLong() );
-
-    pimItems.append( item );
-  }
-
-  bool ok = true;
-  for ( int i = 0; i < pimItems.count(); ++i )
-    ok = ok && cleanupPimItem( pimItems[ i ] );
-
-  return ok;
-}
-
 bool DataStore::addCollectionAttribute(const Collection & col, const QByteArray & key, const QByteArray & value)
 {
   SelectQueryBuilder<CollectionAttribute> qb;
