@@ -18,11 +18,13 @@
 */
 
 #include "dbconfigmysql.h"
-
-#include "../../libs/xdgbasedirs_p.h"
-#include "akdebug.h"
 #include "utils.h"
 
+#include <akdebug.h>
+#include <akstandarddirs.h>
+
+#include <libs/xdgbasedirs_p.h>
+
 #include <QtCore/QDateTime>
 #include <QtCore/QDir>
 #include <QtCore/QProcess>
@@ -50,15 +52,13 @@ QString DbConfigMysql::databaseName() const
 bool DbConfigMysql::init( QSettings &settings )
 {
   // determine default settings depending on the driver
-  QString defaultDbName;
   QString defaultHostName;
   QString defaultOptions;
   QString defaultServerPath;
   QString defaultCleanShutdownCommand;
 
-  const QString socketDirectory = Utils::preferredSocketDirectory( XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) ) );
+  const QString socketDirectory = Utils::preferredSocketDirectory( AkStandardDirs::saveDir( "data", QLatin1String( "db_misc" ) ) );
 
-  defaultDbName = QLatin1String( "akonadi" );
   const bool defaultInternalServer = true;
 #ifdef MYSQLD_EXECUTABLE
    if ( QFile::exists( QLatin1String( MYSQLD_EXECUTABLE ) ) )
@@ -101,7 +101,7 @@ bool DbConfigMysql::init( QSettings &settings )
 
   // read settings for current driver
   settings.beginGroup( driverName() );
-  mDatabaseName = settings.value( QLatin1String( "Name" ), defaultDbName ).toString();
+  mDatabaseName = settings.value( QLatin1String( "Name" ), defaultDatabaseName() ).toString();
   mHostName = settings.value( QLatin1String( "Host" ), defaultHostName ).toString();
   mUserName = settings.value( QLatin1String( "User" ) ).toString();
   mPassword = settings.value( QLatin1String( "Password" ) ).toString();
@@ -113,7 +113,8 @@ bool DbConfigMysql::init( QSettings &settings )
   // verify settings and apply permanent changes (written out below)
   if ( mInternalServer ) {
     mConnectionOptions = defaultOptions;
-    mDatabaseName = defaultDbName;
+    // intentionally not namespaced as we are the only one in this db instance when using internal mode
+    mDatabaseName = QLatin1String("akonadi");
   }
   if ( mInternalServer && (mServerPath.isEmpty() || !QFile::exists( mServerPath ) ) )
     mServerPath = defaultServerPath;
@@ -165,14 +166,14 @@ void DbConfigMysql::startInternalServer()
 {
   const QString mysqldPath = mServerPath;
 
-  const QString akDir   = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/" ) );
-  const QString dataDir = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_data" ) );
-  const QString socketDirectory = Utils::preferredSocketDirectory( XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) ) );
+  const QString akDir   = AkStandardDirs::saveDir( "data" );
+  const QString dataDir = AkStandardDirs::saveDir( "data", QLatin1String( "db_data" ) );
+  const QString socketDirectory = Utils::preferredSocketDirectory( AkStandardDirs::saveDir( "data", QLatin1String( "db_misc" ) ) );
 
   // generate config file
   const QString globalConfig = XdgBaseDirs::findResourceFile( "config", QLatin1String( "akonadi/mysql-global.conf" ) );
   const QString localConfig  = XdgBaseDirs::findResourceFile( "config", QLatin1String( "akonadi/mysql-local.conf" ) );
-  const QString actualConfig = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi" ) ) + QLatin1String( "/mysql.conf" );
+  const QString actualConfig = AkStandardDirs::saveDir( "data" ) + QLatin1String( "/mysql.conf" );
   if ( globalConfig.isEmpty() )
     akFatal() << "Did not find MySQL server default configuration (mysql-global.conf)";
 
